---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: jay0lee

---

The issue tracker is for reporting product deficiencies. "How do I?" questions should be posted to the discussion forum at https://groups.google.com/group/google-apps-manager. When in doubt, start at the discussion forum and return here only when instructed to do so.

Please confirm the following:
* I have upgraded to the latest GAM release from https://github.com/GAM-team/GAM/releases and I still have this issue.
* I am typing the command as described in the GAM Wiki at https://github.com/jay0lee/gam/wiki

Full steps to reproduce the issue:
1.
2.
3.

Expected outcome (what are you trying to do?):

Actual outcome (what errors or bad behavior do you see instead?):
